(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    114794,       2213]
NotebookOptionsPosition[    113585,       2185]
NotebookOutlinePosition[    114088,       2204]
CellTagsIndexPosition[    114045,       2201]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[{
 StyleBox[
  RowBox[{"Stokes", "-", 
   RowBox[{
   "Line", " ", "Drawer", " ", "for", " ", "scalar", " ", "preheating"}]}], 
  "Title"], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"When", " ", "V", 
   RowBox[{"(", "t", ")"}], " ", "is", " ", "given", " ", "by", " ", "an", 
   " ", "inverted", " ", "quadratic", " ", "potential"}], "Title"]}], "Input",
 CellChangeTimes->{{3.8249492389109564`*^9, 3.8249492750362473`*^9}, {
   3.825047765208081*^9, 3.8250478083172555`*^9}, {3.82505560244838*^9, 
   3.825055606739391*^9}, {3.8251130251298943`*^9, 3.8251130755204744`*^9}, 
   3.8251351636295986`*^9},ExpressionUUID->"bc70f9da-5b8a-493c-9dbf-\
7c6d8cd4633d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"FindTP", 
    RowBox[{"(", 
     RowBox[{"find", " ", "turning", " ", "points"}], ")"}], " ", "and", " ", 
    "FindSP", 
    RowBox[{"(", 
     RowBox[{"find", " ", "singular", " ", "points"}], ")"}], " ", "has", " ",
     "to", " ", "be", " ", "customized", " ", "for", " ", "your", " ", "Q"}], 
   " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FindTP", "[", "Q_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "x", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Flatten", "[", 
       RowBox[{"x", "/.", 
        RowBox[{"NSolve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Q", "[", "x", "]"}], "\[Equal]", "0"}], "&&", 
           RowBox[{
            RowBox[{"-", "3"}], "<", 
            RowBox[{"Re", "[", "x", "]"}], "<", "3"}], "&&", 
           RowBox[{
            RowBox[{"-", "3"}], "<", 
            RowBox[{"Im", "[", "x", "]"}], "<", "3"}]}], ",", "x"}], "]"}]}], 
       "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "function", " ", "finds", " ", "the", " ", "initial", " ", 
    "three", " ", "branches", " ", "of", " ", "the", " ", "stokes", " ", 
    "lines", " ", "at", " ", "each", " ", "Turning", " ", "points"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SolTPbranch", "[", "a_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"dx", ",", "x", ",", "y", ",", "bp"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"dx", ":=", 
        RowBox[{"0.001", 
         RowBox[{"(", 
          RowBox[{"x", "+", " ", 
           RowBox[{"I", " ", "y"}]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"bp", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "+", " ", 
           RowBox[{"I", " ", "y"}]}], ")"}], "/.", 
         RowBox[{"NSolve", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Im", "[", 
              RowBox[{
               RowBox[{"Sqrt", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Q", "'"}], "[", "a", "]"}], "dx"}], "]"}], "dx"}], 
              "]"}], "\[Equal]", "0"}], "&&", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"x", ",", "y"}], "}"}], "\[Element]", 
             RowBox[{"Circle", "[", "]"}]}]}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "y"}], "}"}]}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Arg", "[", "bp", "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "StokesGetRep", " ", "and", " ", "Stokesfind1", " ", "finds", " ", "the", 
    " ", "most", " ", "probable", " ", "direction", " ", "from", " ", "the", 
    " ", "given", " ", "point", " ", "on", " ", "the", " ", "stokes", " ", 
    "lines"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"StokesGetRep", "[", 
    RowBox[{"xo_", ",", "\[Theta]o_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ang", ",", "i"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"ang", "[", "1", "]"}], "=", "\[Theta]o"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i", "=", "2"}], ",", 
        RowBox[{"i", "<", "iMax"}], ",", 
        RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"ang", "[", "i", "]"}], "=", 
         RowBox[{"Stokesfind1", "[", 
          RowBox[{"xo", ",", 
           RowBox[{"ang", "[", 
            RowBox[{"i", "-", "1"}], "]"}], ",", " ", 
           RowBox[{"\[CapitalDelta]\[Theta]", " ", 
            RowBox[{"PMi", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "i"}], "+", "2"}], ")"}]}]}]}], "]"}]}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"ang", "[", 
       RowBox[{"iMax", "-", "1"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Stokesfind1", "[", 
     RowBox[{"xo_", ",", "\[Theta]o_", ",", "d\[Theta]_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "f", ",", "\[Theta]", ",", "z", ",", "mini", ",", "i", ",", "tab"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "\[Theta]_", "]"}], ":=", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"Q", "[", 
           RowBox[{"xo", "+", 
            RowBox[{"dr", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", "\[Theta]", "]"}], "+", " ", 
               RowBox[{"I", " ", 
                RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]}], "]"}], 
          "]"}], "dr", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", "\[Theta]", "]"}], "+", " ", 
           RowBox[{"I", " ", 
            RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"f", "[", "\[Theta]_", "]"}], ":=", 
          RowBox[{"NIntegrate", "[", 
           RowBox[{
            RowBox[{"Sqrt", "[", 
             RowBox[{"Q", "[", "z", "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"z", ",", "xo", ",", 
              RowBox[{"N", "[", 
               RowBox[{"xo", " ", "+", "  ", 
                RowBox[{"dr", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", "\[Theta]", "]"}], "+", " ", 
                   RowBox[{"I", " ", 
                    RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]}], 
               "]"}]}], "}"}], ",", 
            RowBox[{"WorkingPrecision", "\[Rule]", "6"}]}], "]"}]}], ";"}], 
        "*)"}], "\[IndentingNewLine]", " ", 
       RowBox[{"mini", "=", 
        RowBox[{
         RowBox[{"Ordering", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{"Im", "[", 
               RowBox[{"f", "[", 
                RowBox[{"\[Theta]o", "-", "d\[Theta]", "+", " ", 
                 RowBox[{"d\[Theta]", " ", 
                  RowBox[{"i", "/", "PMi"}]}]}], "]"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "0", ",", 
               RowBox[{"2", " ", "PMi"}]}], "}"}]}], "]"}], ",", "1"}], "]"}],
          "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"\[Theta]o", "-", "d\[Theta]", "+", " ", 
        RowBox[{"d\[Theta]", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"mini", "-", "1"}], ")"}], "/", "PMi"}]}]}]}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "GetStokesTable", " ", "generates", " ", "tables", " ", "of", " ", "the", 
    " ", "points", " ", "on", " ", "the", " ", "stokes", " ", "lines", " ", 
    "using", " ", "StokesGetRep"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GetStokesTable", "[", 
    RowBox[{"k_", ",", "j_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i", ",", "nn"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"sX", "[", 
        RowBox[{"[", 
         RowBox[{"k", ",", "j", ",", "1"}], "]"}], "]"}], "=", 
       RowBox[{"TP", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"angS", "[", 
        RowBox[{"[", 
         RowBox[{"k", ",", "j", ",", "1"}], "]"}], "]"}], "=", 
       RowBox[{"TPbranch", "[", 
        RowBox[{"[", 
         RowBox[{"k", ",", "j"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i", "=", "2"}], ",", 
        RowBox[{"i", "<", 
         RowBox[{"stepN", "+", "1"}]}], ",", 
        RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"sX", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "j", ",", "i"}], "]"}], "]"}], "=", 
          RowBox[{
           RowBox[{"sX", "[", 
            RowBox[{"[", 
             RowBox[{"k", ",", "j", ",", 
              RowBox[{"i", "-", "1"}]}], "]"}], "]"}], "+", 
           RowBox[{"N", "[", 
            RowBox[{"dr", " ", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{"I", " ", 
                RowBox[{"angS", "[", 
                 RowBox[{"[", 
                  RowBox[{"k", ",", "j", ",", 
                   RowBox[{"i", "-", "1"}]}], "]"}], "]"}]}], ")"}]}]}], 
            "]"}]}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"SPTP", "=", 
          RowBox[{"Join", "[", "TP", "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"domain", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{"SPTP", "[", 
                 RowBox[{"[", "nn", "]"}], "]"}], "]"}], "-", "0.04"}], "<", 
              RowBox[{"Re", "[", 
               RowBox[{"sX", "[", 
                RowBox[{"[", 
                 RowBox[{"k", ",", "j", ",", "i"}], "]"}], "]"}], "]"}], "<", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{"SPTP", "[", 
                 RowBox[{"[", "nn", "]"}], "]"}], "]"}], "+", "0.04"}]}], "&&", 
             RowBox[{
              RowBox[{
               RowBox[{"Im", "[", 
                RowBox[{"SPTP", "[", 
                 RowBox[{"[", "nn", "]"}], "]"}], "]"}], "-", "0.04"}], "<", 
              RowBox[{"Im", "[", 
               RowBox[{"sX", "[", 
                RowBox[{"[", 
                 RowBox[{"k", ",", "j", ",", "i"}], "]"}], "]"}], "]"}], "<", 
              RowBox[{
               RowBox[{"Im", "[", 
                RowBox[{"SPTP", "[", 
                 RowBox[{"[", "nn", "]"}], "]"}], "]"}], "+", "0.04"}]}]}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"nn", ",", 
              RowBox[{"nTP", "+", "nSP"}]}], "}"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"i", ">", "10"}], "&&", 
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"DeleteDuplicates", "[", "domain", "]"}], "]"}], "==", 
             "2"}]}], ",", 
           RowBox[{"Break", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"sX", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "j", ",", "i"}], "]"}], "]"}], "]"}], ">", 
            "Swindow"}], ",", 
           RowBox[{"Break", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"angS", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "j", ",", "i"}], "]"}], "]"}], "=", " ", 
          RowBox[{"StokesGetRep", "[", 
           RowBox[{
            RowBox[{"sX", "[", 
             RowBox[{"[", 
              RowBox[{"k", ",", "j", ",", "i"}], "]"}], "]"}], ",", 
            RowBox[{"angS", "[", 
             RowBox[{"[", 
              RowBox[{"k", ",", "j", ",", 
               RowBox[{"i", "-", "1"}]}], "]"}], "]"}]}], "]"}]}]}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"sX", "[", 
          RowBox[{"[", 
           RowBox[{"k", ",", "j", ",", "n"}], "]"}], "]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "stepN"}], "}"}]}], "]"}]}]}], "]"}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Your", " ", "setups", " ", "here"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Q", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{"-", "1"}], "-", 
    RowBox[{"t", "^", "2"}], "+", 
    RowBox[{"0.1", " ", "I"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{"Q", "[", "t", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dr", "=", "0.01"}], ";", 
  RowBox[{"(*", " ", 
   RowBox[{"Step", " ", "of", " ", "the", " ", "move"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"stepN", "=", "250"}], ";", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Maximum", " ", "number", " ", "of", " ", "steps", " ", "for", " ", "each",
     " ", "stokes", " ", "line"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"\[CapitalDelta]\[Theta]", " ", "=", " ", "0.4"}], ";", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "StokesGetRep", " ", "searches", " ", "direction", " ", "in", " ", "the",
       " ", "range"}], " ", "-", "\[CapitalDelta]\[Theta]"}], "\[Rule]", " ", 
    RowBox[{
     RowBox[{"+", 
      RowBox[{"\[CapitalDelta]\[Theta]", ".", " ", "Make"}]}], " ", "this", 
     " ", "parameter", " ", "small", " ", "if", " ", "stokes", " ", "lines", 
     " ", 
     RowBox[{"merge", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"PMi", "=", "10"}], ";", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "The", " ", "search", " ", "step", " ", "of", " ", "the", " ", 
     "direction", " ", "is", " ", 
     RowBox[{"\[CapitalDelta]\[Theta]", "/", "PMi"}]}], ",", " ", 
    RowBox[{"repeated", " ", "iMax", " ", 
     RowBox[{"times", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"iMax", "=", "4"}], ";", 
  RowBox[{"(*", " ", 
   RowBox[{"Depth", " ", "of", " ", "the", " ", "direction", " ", "search"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Swindow", "=", "4."}], ";", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"StokesGetRep", " ", "stops", " ", "when", " ", 
     RowBox[{"Abs", "[", "sx", "]"}]}], ">", 
    RowBox[{
    "Swindow", " ", "or", " ", "reaches", " ", "at", " ", "another", " ", 
     "turning", " ", "points", " ", "or", " ", "singular", " ", "points"}]}], 
   "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"===", "===", 
     RowBox[{"\[Equal]", "\:672c\:4f53"}], "===", "===", "===", "==="}], "=", 
    RowBox[{"===", "===", "===", "===", "\[Equal]"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"TP", "=", 
   RowBox[{"FindTP", "[", "Q", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<Your turning points are at\>\"", " ", 
  RowBox[{"MatrixForm", "[", "TP", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nTP", "=", " ", 
   RowBox[{"Length", "[", "TP", "]"}]}], 
  RowBox[{"(*", " ", 
   RowBox[{"number", " ", "of", " ", "Turning", " ", "Points"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nSP", "=", " ", "0"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"number", " ", "of", " ", "Singular", " ", "Points"}], " ", "*)"}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TPbranch", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"SolTPbranch", "[", 
      RowBox[{"TP", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "nTP"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MatrixForm", "[", "TPbranch", "]"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Initializing", " ", "the", " ", "Matrices"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bt", "=", 
    RowBox[{"ConstantArray", "[", 
     RowBox[{
      RowBox[{"N", "[", "0", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"nTP", ",", "3"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "nTP"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "3"}], "}"}]}], "]"}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sX", "=", 
    RowBox[{"ConstantArray", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"nTP", ",", "3", ",", "stepN"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "nTP"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "stepN"}], "}"}]}], "]"}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"angS", "=", 
    RowBox[{"ConstantArray", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"nTP", ",", "3", ",", "stepN"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "nTP"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "stepN"}], "}"}]}], "]"}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"AbsoluteTiming", "[", 
  RowBox[{
   RowBox[{"StokesList", "=", 
    RowBox[{"ParallelTable", "[", 
     RowBox[{
      RowBox[{"Catenate", "[", 
       RowBox[{"GetStokesTable", "[", 
        RowBox[{"k", ",", "j"}], "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", "nTP"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}]}], ";"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ComplexListPlot", "[", 
    RowBox[{
     RowBox[{"Catenate", "[", "StokesList", "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], "-", 
         RowBox[{"2", "I"}]}], ",", 
        RowBox[{"3", "+", 
         RowBox[{"2", "I"}]}]}], "}"}]}]}], "]"}], ",", 
   RowBox[{"ComplexListPlot", "[", 
    RowBox[{"TP", ",", 
     RowBox[{"PlotMarkers", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\[FilledCircle]", ",", "50"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], "-", 
         RowBox[{"2", "I"}]}], ",", 
        RowBox[{"2", "+", 
         RowBox[{"2", "I"}]}]}], "}"}]}]}], "]"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.8230381122087593`*^9, 3.823038121157728*^9}, {
   3.8230384041556463`*^9, 3.8230384231245923`*^9}, {3.8230385171385546`*^9, 
   3.8230385458016977`*^9}, {3.82303858585093*^9, 3.823038595328173*^9}, {
   3.823038628758222*^9, 3.8230386742339635`*^9}, {3.823039321065159*^9, 
   3.823039327611306*^9}, {3.8230393789031305`*^9, 3.823039397235064*^9}, 
   3.8230394485073433`*^9, {3.8230397398403435`*^9, 3.823039741102245*^9}, {
   3.823039819626861*^9, 3.823039879574297*^9}, {3.8230399187100954`*^9, 
   3.823039945712809*^9}, {3.823040135933854*^9, 3.823040173961895*^9}, {
   3.8230402475720735`*^9, 3.823040247913655*^9}, {3.823040293852997*^9, 
   3.8230402944601955`*^9}, {3.823040520236519*^9, 3.8230405229659767`*^9}, {
   3.8230459500720778`*^9, 3.823045951788929*^9}, 3.823046199721779*^9, {
   3.823046404479682*^9, 3.8230464087514744`*^9}, {3.823046444328246*^9, 
   3.8230464468789396`*^9}, {3.8230465398707895`*^9, 
   3.8230465482199416`*^9}, {3.8230466725470653`*^9, 3.823046680312364*^9}, 
   3.8230467783291636`*^9, {3.823046832993461*^9, 3.823046851789612*^9}, {
   3.823046898352391*^9, 3.823046898653783*^9}, {3.8230469448880424`*^9, 
   3.823046945320058*^9}, {3.823047122436264*^9, 3.823047129043346*^9}, {
   3.8230472836014724`*^9, 3.823047284886017*^9}, {3.823047472713174*^9, 
   3.823047497235473*^9}, {3.8230476296740885`*^9, 3.8230476334474225`*^9}, {
   3.8231192209477277`*^9, 3.8231192635404897`*^9}, {3.8231193140373206`*^9, 
   3.8231193491660028`*^9}, {3.823119654168016*^9, 3.823119654684041*^9}, 
   3.823120136137907*^9, {3.8231201805058994`*^9, 3.8231201894783754`*^9}, {
   3.8231203029018183`*^9, 3.8231203189085236`*^9}, {3.823120600136722*^9, 
   3.823120600598389*^9}, {3.823120962225477*^9, 3.8231209627512693`*^9}, {
   3.8231214638985395`*^9, 3.8231214677799473`*^9}, 3.8232151075611963`*^9, {
   3.823215155528163*^9, 3.823215157621708*^9}, {3.823215238855918*^9, 
   3.8232152391827455`*^9}, {3.823215377406497*^9, 3.8232153955586233`*^9}, {
   3.82365417587976*^9, 3.823654208645379*^9}, {3.8236544326919403`*^9, 
   3.823654433098284*^9}, {3.823654782389432*^9, 3.823654803899276*^9}, {
   3.823655767160862*^9, 3.823655792332571*^9}, {3.8236564200224752`*^9, 
   3.823656420692004*^9}, {3.8236571861142287`*^9, 3.8236571896297655`*^9}, {
   3.823911444090046*^9, 3.82391146070953*^9}, {3.8239114911088576`*^9, 
   3.8239115323653593`*^9}, {3.8239122566022263`*^9, 3.823912285990092*^9}, {
   3.8239128133711576`*^9, 3.8239128589185023`*^9}, {3.8244404636918907`*^9, 
   3.8244404715509644`*^9}, {3.8244409223790913`*^9, 3.8244409869730706`*^9}, 
   3.8244416681456084`*^9, {3.8244425651996264`*^9, 3.824442666927389*^9}, {
   3.824443277817015*^9, 3.824443298957965*^9}, 3.8244439576297007`*^9, {
   3.82444399370301*^9, 3.8244440094887915`*^9}, {3.8244441515827875`*^9, 
   3.8244441905203304`*^9}, {3.8244447142705107`*^9, 3.824444739553271*^9}, {
   3.8249516839273605`*^9, 3.824951948692665*^9}, {3.8249519903646326`*^9, 
   3.8249526771768026`*^9}, {3.8249527168795843`*^9, 3.824952755863985*^9}, 
   3.8249527909423943`*^9, 3.82495282189541*^9, {3.824952953677147*^9, 
   3.824952954283682*^9}, 3.8250384613645315`*^9, {3.825038857164904*^9, 
   3.825038884160663*^9}, {3.8250389187083693`*^9, 3.825038924629775*^9}, {
   3.825038955895584*^9, 3.825039047926175*^9}, {3.825039516177226*^9, 
   3.825039531911244*^9}, {3.825039575145588*^9, 3.825039593270872*^9}, 
   3.8250401719890795`*^9, {3.8250402263644457`*^9, 3.825040235536263*^9}, {
   3.8250404054520016`*^9, 3.82504041601469*^9}, 3.8250404792440443`*^9, {
   3.825040627439445*^9, 3.825040635193365*^9}, 3.825040765405196*^9, {
   3.825041526833226*^9, 3.8250415500049105`*^9}, {3.8250417475828156`*^9, 
   3.8250418357080345`*^9}, {3.8250420103641825`*^9, 
   3.8250420141147404`*^9}, {3.825042101788607*^9, 3.8250421082547398`*^9}, {
   3.8250422575082345`*^9, 3.82504227567653*^9}, {3.8250425843349686`*^9, 
   3.82504263433325*^9}, {3.825042810989385*^9, 3.825042880551962*^9}, {
   3.825043234114007*^9, 3.8250432386610556`*^9}, {3.825043280536135*^9, 
   3.8250432864262056`*^9}, {3.825043737131957*^9, 3.8250438012444105`*^9}, {
   3.825043851161379*^9, 3.8250438881610003`*^9}, {3.8250440370674615`*^9, 
   3.8250440720674562`*^9}, {3.8250444298954983`*^9, 3.825044451941949*^9}, {
   3.8250451040988255`*^9, 3.825045124210023*^9}, {3.8250453834577937`*^9, 
   3.8250454105359616`*^9}, {3.825045618426635*^9, 3.825045652442179*^9}, {
   3.825046067973283*^9, 3.825046096754877*^9}, {3.8250471519422*^9, 
   3.825047173536248*^9}, {3.825047494848358*^9, 3.8250475216146336`*^9}, {
   3.8250528298503647`*^9, 3.825052881701392*^9}, {3.8250532259724817`*^9, 
   3.825053241021679*^9}, {3.825053729666233*^9, 3.825053736857321*^9}, {
   3.825054130770846*^9, 3.825054141616915*^9}, {3.825054360223475*^9, 
   3.825054368223543*^9}, {3.8250546153484526`*^9, 3.825054630973682*^9}, {
   3.825054663051591*^9, 3.8250546863956776`*^9}, {3.8250551271145334`*^9, 
   3.825055137520564*^9}, {3.8250557124580793`*^9, 3.825055732723209*^9}, {
   3.825056097178259*^9, 3.8250561053021584`*^9}, {3.8250565283022213`*^9, 
   3.8250565715832944`*^9}, {3.8250572379272175`*^9, 3.825057246770585*^9}, {
   3.8250572942861257`*^9, 3.8250573176772566`*^9}, {3.8250574320831165`*^9, 
   3.825057474395358*^9}, {3.825104572083064*^9, 3.8251045836610184`*^9}, {
   3.8251046288644023`*^9, 3.8251046461299467`*^9}, {3.8251352268642664`*^9, 
   3.825135227290603*^9}, {3.825135311567214*^9, 3.825135333523367*^9}, {
   3.8251354048019924`*^9, 3.8251354735358324`*^9}, {3.825135831301956*^9, 
   3.8251358323023834`*^9}, {3.838967116021149*^9, 3.8389671223995156`*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"b64d2191-17bf-44d5-9569-bb0d8fa1db1c"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJw12Hk0VV/YB3DzlRCSH5LpRkhIiAz7JhWJUEQJDUI/U+VnHiLzTJGhSGWK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       "]]},
     Annotation[#, "Charting`Private`Tag$17374#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{373., Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-3, 3}, {-9.999999265306139, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.825038887192035*^9, 3.825038927817092*^9, 3.825038978785578*^9, {
   3.8250390251450014`*^9, 3.825039053566888*^9}, 3.825039533348454*^9, 
   3.8250396081293316`*^9, 3.8250401744901676`*^9, 3.825040236707527*^9, 
   3.8250404803994865`*^9, 3.825040766516387*^9, 3.825041841473078*^9, 
   3.8250420188949404`*^9, 3.8250421088480763`*^9, 3.825042292613776*^9, 
   3.8250426400668793`*^9, 3.825042891066882*^9, 3.8250432423793187`*^9, {
   3.825043282270039*^9, 3.8250432924574986`*^9}, 3.8250438920356407`*^9, 
   3.825044075973096*^9, 3.8250444670044565`*^9, 3.8250451267856255`*^9, 
   3.8250452943481417`*^9, 3.8250454226140413`*^9, 3.8250456614261827`*^9, 
   3.8250461019887056`*^9, 3.825047178660862*^9, 3.8250475281762094`*^9, 
   3.8250528852647095`*^9, 3.8250532439715323`*^9, 3.8250537605543213`*^9, 
   3.8250541444645967`*^9, 3.8250543716140256`*^9, 3.8250546900828094`*^9, 
   3.825055140926216*^9, 3.8250557376137047`*^9, 3.825056111441887*^9, 
   3.8250565731451316`*^9, 3.825057252082528*^9, 3.825057318582635*^9, 
   3.825057479379449*^9, 3.82510375234797*^9, 3.825104584811177*^9, {
   3.82510462931707*^9, 3.8251046477856045`*^9}, {3.825135216739256*^9, 
   3.825135228833023*^9}, 3.825135320051409*^9, {3.825135425832877*^9, 
   3.8251354758173914`*^9}, 3.838967123130645*^9},
 CellLabel->"Out[71]=",ExpressionUUID->"d1319bcb-e1d5-4caa-ada4-6eb2474fa462"],

Cell[BoxData[
 RowBox[{"\<\"Your turning points are at\"\>", " ", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", 
    TagBox[GridBox[{
       {
        RowBox[{
         RowBox[{"-", "0.049937771837002445`"}], "-", 
         RowBox[{"1.0012461141278124`", " ", "\[ImaginaryI]"}]}]},
       {
        RowBox[{"0.04993777183700243`", "\[VeryThinSpace]", "+", 
         RowBox[{"1.0012461141278126`", " ", "\[ImaginaryI]"}]}]}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     Column], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{
  3.825038887192035*^9, 3.825038927817092*^9, 3.825038978785578*^9, {
   3.8250390251450014`*^9, 3.825039053566888*^9}, 3.825039533348454*^9, 
   3.8250396081293316`*^9, 3.8250401744901676`*^9, 3.825040236707527*^9, 
   3.8250404803994865`*^9, 3.825040766516387*^9, 3.825041841473078*^9, 
   3.8250420188949404`*^9, 3.8250421088480763`*^9, 3.825042292613776*^9, 
   3.8250426400668793`*^9, 3.825042891066882*^9, 3.8250432423793187`*^9, {
   3.825043282270039*^9, 3.8250432924574986`*^9}, 3.8250438920356407`*^9, 
   3.825044075973096*^9, 3.8250444670044565`*^9, 3.8250451267856255`*^9, 
   3.8250452943481417`*^9, 3.8250454226140413`*^9, 3.8250456614261827`*^9, 
   3.8250461019887056`*^9, 3.825047178660862*^9, 3.8250475281762094`*^9, 
   3.8250528852647095`*^9, 3.8250532439715323`*^9, 3.8250537605543213`*^9, 
   3.8250541444645967`*^9, 3.8250543716140256`*^9, 3.8250546900828094`*^9, 
   3.825055140926216*^9, 3.8250557376137047`*^9, 3.825056111441887*^9, 
   3.8250565731451316`*^9, 3.825057252082528*^9, 3.825057318582635*^9, 
   3.825057479379449*^9, 3.82510375234797*^9, 3.825104584811177*^9, {
   3.82510462931707*^9, 3.8251046477856045`*^9}, {3.825135216739256*^9, 
   3.825135228833023*^9}, 3.825135320051409*^9, {3.825135425832877*^9, 
   3.8251354758173914`*^9}, 3.838967123130645*^9},
 CellLabel->"Out[73]=",ExpressionUUID->"b3f524a0-8d2e-403b-9dc7-cc57f2a49bfa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.3274943`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{
  3.825038887192035*^9, 3.825038927817092*^9, 3.825038978785578*^9, {
   3.8250390251450014`*^9, 3.825039053566888*^9}, 3.825039533348454*^9, 
   3.8250396081293316`*^9, 3.8250401744901676`*^9, 3.825040236707527*^9, 
   3.8250404803994865`*^9, 3.825040766516387*^9, 3.825041841473078*^9, 
   3.8250420188949404`*^9, 3.8250421088480763`*^9, 3.825042292613776*^9, 
   3.8250426400668793`*^9, 3.825042891066882*^9, 3.8250432423793187`*^9, {
   3.825043282270039*^9, 3.8250432924574986`*^9}, 3.8250438920356407`*^9, 
   3.825044075973096*^9, 3.8250444670044565`*^9, 3.8250451267856255`*^9, 
   3.8250452943481417`*^9, 3.8250454226140413`*^9, 3.8250456614261827`*^9, 
   3.8250461019887056`*^9, 3.825047178660862*^9, 3.8250475281762094`*^9, 
   3.8250528852647095`*^9, 3.8250532439715323`*^9, 3.8250537605543213`*^9, 
   3.8250541444645967`*^9, 3.8250543716140256`*^9, 3.8250546900828094`*^9, 
   3.825055140926216*^9, 3.8250557376137047`*^9, 3.825056111441887*^9, 
   3.8250565731451316`*^9, 3.825057252082528*^9, 3.825057318582635*^9, 
   3.825057479379449*^9, 3.82510375234797*^9, 3.825104584811177*^9, {
   3.82510462931707*^9, 3.8251046477856045`*^9}, {3.825135216739256*^9, 
   3.825135228833023*^9}, 3.825135320051409*^9, {3.825135425832877*^9, 
   3.8251354758173914`*^9}, 3.838967123818736*^9},
 CellLabel->"Out[81]=",ExpressionUUID->"1a2dc46c-ea9b-4fab-8cb0-c2da941fe077"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}}, {}, {{}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.004583333333333334], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwV1Wdczg0bxvFrVIgUikqkSHYIxR3JSlQ0RBkNFUpFRkpRRLopIjSlQUZK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        "]]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
       0.004583333333333334], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwV13k4FPr3B3CUrFNCKpWtDS2UmhbLB9VNEQpdSqFIosjaVa6dSjfh22KN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        "]]}, 
      {RGBColor[0.560181, 0.691569, 0.194885], PointSize[
       0.004583333333333334], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVlXc814v/xT+DS0rClSgrFRmNXxRu9YpChFBpEFERDbpWpXRVNBQpipaE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        "]]}, 
      {RGBColor[0.922526, 0.385626, 0.209179], PointSize[
       0.004583333333333334], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVlWc814v7xr+Dk0LCKaNkVRyj8QsHp7o/FCGESioldIgGZRWlo6JBpFSa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        "]]}, 
      {RGBColor[0.528488, 0.470624, 0.701351], PointSize[
       0.004583333333333334], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwV1/c/FfoDBnBEdkOS1KW0UIlEw3jQUskI3bREJC0po1tX2QolmoQUXZzj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        "]]}, 
      {RGBColor[0.772079, 0.431554, 0.102387], PointSize[
       0.004583333333333334], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVlmc81g0Dhe+BUikVhTQoaVMqlKfz51FGRkaDFiJSSEt5EKmkUEplJqMo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        "]]}}, {{}, {}}}, {}, {{}, {{{}, {}, {}, {}}, {}}}}, {{{}, {}}, {}, \
{{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      GeometricTransformationBox[InsetBox[
        StyleBox["\[FilledCircle]",
         StripOnInput->False,
         GraphicsBoxOptions->{DefaultBaseStyle->Directive[
           PointSize[0.012833333333333334`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]]}], {0., 0.}, Automatic, Offset[
        50]], {{{-0.049937771837002445`, -1.0012461141278124`}}, {{
       0.04993777183700243, 
       1.0012461141278126`}}}]}, {{}, {}}}, {}, {{}, {{{}, {}, {}, {}}, {}}}}},
  AspectRatio->Automatic,
  Axes->True,
  AxesOrigin->{0, 0},
  CoordinatesToolOptions:>{"DisplayFunction" -> (Identity[
       Part[#, 1]] + I Identity[
        Part[#, 2]]& ), "CopiedValueFunction" -> (Identity[
       Part[#, 1]] + I Identity[
        Part[#, 2]]& )},
  DisplayFunction->Identity,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{373., Automatic},
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "MessagesHead" -> ComplexListPlot},
  PlotRange->{{-2, 3}, {-2, 2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.825038887192035*^9, 3.825038927817092*^9, 3.825038978785578*^9, {
   3.8250390251450014`*^9, 3.825039053566888*^9}, 3.825039533348454*^9, 
   3.8250396081293316`*^9, 3.8250401744901676`*^9, 3.825040236707527*^9, 
   3.8250404803994865`*^9, 3.825040766516387*^9, 3.825041841473078*^9, 
   3.8250420188949404`*^9, 3.8250421088480763`*^9, 3.825042292613776*^9, 
   3.8250426400668793`*^9, 3.825042891066882*^9, 3.8250432423793187`*^9, {
   3.825043282270039*^9, 3.8250432924574986`*^9}, 3.8250438920356407`*^9, 
   3.825044075973096*^9, 3.8250444670044565`*^9, 3.8250451267856255`*^9, 
   3.8250452943481417`*^9, 3.8250454226140413`*^9, 3.8250456614261827`*^9, 
   3.8250461019887056`*^9, 3.825047178660862*^9, 3.8250475281762094`*^9, 
   3.8250528852647095`*^9, 3.8250532439715323`*^9, 3.8250537605543213`*^9, 
   3.8250541444645967`*^9, 3.8250543716140256`*^9, 3.8250546900828094`*^9, 
   3.825055140926216*^9, 3.8250557376137047`*^9, 3.825056111441887*^9, 
   3.8250565731451316`*^9, 3.825057252082528*^9, 3.825057318582635*^9, 
   3.825057479379449*^9, 3.82510375234797*^9, 3.825104584811177*^9, {
   3.82510462931707*^9, 3.8251046477856045`*^9}, {3.825135216739256*^9, 
   3.825135228833023*^9}, 3.825135320051409*^9, {3.825135425832877*^9, 
   3.8251354758173914`*^9}, 3.838967124021174*^9},
 CellLabel->"Out[82]=",ExpressionUUID->"3fdb8df1-4e70-4ca7-9dc1-8eec2c2f0ef7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Q", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{"-", "1"}], "-", 
    RowBox[{"t", "^", "2"}], "+", 
    RowBox[{"0.1", " ", "I"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8251358179425697`*^9, 
  3.8251358206460247`*^9}},ExpressionUUID->"50481924-8e00-4c4e-9053-\
71e97dfd0c9a"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}}, {}, {{}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.004583333333333334], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwV1mdczwsbBvD/yDgSklRKmsbJySitIzMNaagkJJVCoSJRpxTqNBQNQtJA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        "]]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
       0.004583333333333334], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwV1/c7Ff4bBnArlZHsbEVI+KiQSt7ILCEZUTJCRmaUopQRpZIoKWRlHOMM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        "]]}, 
      {RGBColor[0.560181, 0.691569, 0.194885], PointSize[
       0.004583333333333334], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwV1mc81Q8bBvAzQsqIShqUylYSQv9yo4wkipCQIiWJlKaoKCsNSYM0SJFR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        "]]}, 
      {RGBColor[0.922526, 0.385626, 0.209179], PointSize[
       0.004583333333333334], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVlmc8Fvofhp8RUijqSE5ERYSQEZ3q90NGiEpIVpGSyiiVEhVlpU4ySlKy
sosUKn2RSEiEjENRVtazl2f8+7+4P/eb+/pcb29Vn6D9fiQCgcD7k/931qK6
pJCkQiTTaZynKEZBPYF7afdX5SHTlxtZAgUKqjQNcnfIykIqkQETYjoUpC65
Jl5i/30kYV3aJ21GQS3D21J0O28jygx23uZMQYku4dpZ/Iuo/25357ETFMRQ
ET7asd8XGkz8HZIjKKi2t9xVNjMGDH3UzH4lUdAjua6cli0pkH9z1MAon4L4
XvRrXbKZkJYTHlv0moJKnZc8P83Jhpg3KwfXdlDQ6UNRJ/f5PYXnEvKXan5S
kI43T92oqxgGnFatduJQEFvfNCRx7XNYlKVQPSNFRQumBjnFByrA33UysUiV
ikRmOj2f4iuhTab6iL8xFWl/6FqSWvsKDgSnudjaUZGbTRj2plbDf52hdtqH
qSimVem8ptobOGrghGXOUdF4q9nhh661UPnwEFqZQEVWbX62yxIAFon77FR8
TEUbs5/sSRmqg9NLYvV3VVKRltdylgqrHnplSjYEtlCRruKVR6Uy7wGt6Fx1
f5iKirHSgUT1Rvhxd3RyjP6HP/5G8uTOD3BNjlFjIElDWVJyTx84N0H8voz9
eco0pFjhv+vTqWZIumM+LW9IQymuMMKN/gjpHVPRcbtpSGvTMvOLD1rg1a2i
diVvGmrge2Vznn+Cr3YnV70IpSG3jjJSWHMrUCS1j9gk0NC73VSi1VAbjKYf
tSRm0dD6RgPiSno7dGtmar5+SUMd3msu6y7uAPX4mKS01j/7iKjwPJkvEDYZ
xD0z8sffyjIxSP8Cn6zdjjiyaWgikrnu+PpOqDaWMHaUpqNtWxhSGaWdkK/2
conjejq6NUZjfd7aBSkrfb87mNJRUXTS5YL6LpDb3Ch5xpGOPqrqkaLsvsId
azXDVD86GofPse49X0HmSIxXdTgd3Ui7pjDg1Q3cLUebhUl0tOG0YeHByW74
tchcz7KAjt5bTJh+C+mBjt616Tff0VEKIcqSx+sBc56yJrObjvxq1+xTut4L
L5WUa7ym6cj4UpUHlv4GGmZKuz8SGWh5w2knibRvIDxTO3lAgYF+S26w/azc
B925nnEjmxmocd8ATn3aB0W9go2BlgwU7IqTRbr9oLz8ASh5MNAaz/yxE9X9
cHe3sWv7GQb66CNl0o0HQDy6a+5yPAMdjljlOvJxAKLknhxzzGIgzr115+f2
DoLwSdCwahUD3anQSV3oG4RL+jtdGO0MpNFuUrn4yH/AqpP63PSLgVbJYNnq
yf+A5LtW5u0CA4k7WgceDx4CGbEtDuVyTMT816FVnjMEik933c7XZKJbB5f2
Hb8yDKGP4yLfYSZSU/34q1r8O3y+1xbY68pEtVPXqZK3v4PGneXec4FMtKlf
5Urpkh8QFXfAUTyGia5s8E9Td/gBHm/ufsOZTNQd9Kz0cdIPMJ774h1eyUSa
b1iNCj0/YLnqssmXrUxU3H5M3UdhBC5oz8zL/WQinR+9scXuIzC8tYUdxGOi
ZzSrKcajEbC0yBe1ybKQvliV7c7REShxiJbYpMlCG5rqn7mqjYJM7pXzhZiF
VsW2rQzxH4VgbviYxkEWWmLz7WJC8Sh0OYQdKAhiIcHi0eGcuVEwzA19vzGW
heqeaxFv6f+EldkzV1sesVD0wXPrz4f+BMbjoztPvmIhKwJYelf9hO7M/xak
PrPQah/l76t4P+Fh4eL5L2MsNPM+IuzL9l9w9KXhaIqAhUBtSDb+yi/Qrj/c
c/AvNrobu73YrOEXMNoSP67RYSNN9zfnWhaNAevUtT6SJRvVbd6G91mPAUfq
/OSkBxu5kmqW9MePAa8kgPM5lI3merb2HG4bA7699+KXiWx0o/DV40mZcRDO
OClk5LLR0e4kZ7RvHO6MErVz3rKRhejU0rTkcVjX9wwVd7PRuk029TM941DZ
7un0YoaNiM7rL1goTIDV+6XH3yzioCyD1i7/QxMgpYb9xtZwEJI7u/n2wwno
ign1XWbEQcMUxYQXwxNwf7LgiOkeDoroaBjrU5kEL9shb18/DtoROfikzWcS
Xj0y030WwUECbYZnXe4kyNDzhLxUDqodlFKsHJ+EY9ZLPluV/eET1HqfakzB
u4zAzLtNf3jTnXczAqZAntJ1aniYg1SGHp/wLJmCQutZuh2bg8jXiGZr56Zg
+2OJ8JplXDS+wVdhRPc3dLBUSRs1uKjlY+N8dshv8HHYHp+CuajklHrz0Re/
gZnnspzkxkV94UOhDMZvOP0q3igphIsW3UxZd914Gsaa3h5SSeAivQd2X1aE
TYPnt/krz7K5yKOQFJlTMw09E+vydr7horjqGi2DhWnYw3H+1P6Vi9LMJU7e
2T4DW7aOnI2c4aLctgNFsxEzsOr8KSVdMR6qcMmesoUZ4Feym74r8VDdj3mN
AsIsjNCjgu8Y89DngB3+Yuaz0LRFRtHMkYeGD99j6EbPwhWK9OYV/jw050K9
eqhxFkzKpM3HrvKQ0N5O+obYHFBPSrtUpfOQjEVe+jOrOSjSlA6Ir+AhZVOR
2kDsHPhOSEW6t/LQq5fL33R+nAP3gEujDr94yGHLur0tkvPgNDthZS7gofEy
g7E623mwC3YuNpJfQJFalpeqb86DBb1hmabuApIvcFn2vG0e/jmvF7rGZgG5
yhl2fRWngAE3s2/ZkQVU3r9YZLSRAuvTHc9uuLSAlj4Z0rpvTYEVpkQZ0+QF
5OdfcZB3nALk/oqCPSULCHRjb3jEUYAedtTC58MCWs12r3hXQIGfCvLD54cX
0Nl3et9VWijwtbo57CZ7AY0897A/MUUBPV6wbv1yPnLMiaspl6TCrX8Ux1ma
fFSbWqnO06TC78vvH2pb8JFW3I9kc1sqWL875eTjwUfpl6SINwOokCv6a8n9
c3wkcdok8GsCFYhmUNd+m48CSka4xGIqJFMoYRsK+Kh9OuGGXisV1LLW6YfX
85GelqGs9zQVqhwPTHUO8FFywNDDW0tpsFt044kGg49YhTEab7VoMFhW5XZF
WoDcpnQrf9vR4LTXlGyvugBNvr63XXSSBmKlsuV7sABdSBQ1rkikQeaC6d4P
bgIk7nV8j0YJDYxsfea3nxWgVN2Onu1tNGi/n3C7MlGANhC3eu2boYHfRIWO
dr4Aveh6NO4nRQeB0WBbDgiQea540CVtOqReJ5/6u1+A5pPju0Lt6TCxLvDb
C5oAPYyWMg46RQfT+j5zeykh2n323/QTiXS46W1R9ktNiFg+cgLfEjoMCUpX
RyAhytmfetirjQ66DxVu/OUmRHvNFRoPztDh2rZoSukZIRLoZ2x0kmLA175Z
d6tEIaoxKt9loM2Aiysaw0R5QnTOtPnICnsGrHV4kFoNQqS/YyiSfpIBH+KC
K0L6hWgW0zO+3mTAyfdWHZvoQlS4S7LmRTEDZIVrZn5KiZCfzdre5FYGVJnQ
F2eqi5CqvRH97DQDPM+2qLlgERKbCCkwXcoEvoNcv+4hEZq6VuYp2sSEjE3u
iZKhItS+Zlrugy0Ttonnop+3RKi8auPHhAAm9I/M0N4+FaHU/Ucj9iYwIazW
KD+tXoQuzmZtkS9iwqr0SLfgQRHyjBuaGGxhwqvQZilbpgiZrVfMfDLFhE0a
i38kSRBwZpx2i70kC6j7D7JvryRg7uxOJluDBdURBTKJqgTs7LRPNceGBVcK
OGrxmwm4vNp3j4M/C6y+2uyI+YeApZXPX+TGskBaeP9AtA0Bn4iOy8t9yoJu
jamTV50J+MPkg07HZhZkOJlGR/gQsKpDqYA3zgKfyPgHl4IIOOIFaOaLs0Gz
sL/8wmUCbpg6U2yszoYGpjH3ejwBS6io6zRbssHdPAXfTSNge5f+Mlc/NjBu
U2Mf5xBwUmKi3uR1NtwadOgoeU7AvQ2oIiyXDeoaJfKvawn4by7NQLKRDRAq
6dX8iYAP6+a/TP/JhoP1x/K6vxFwnp/b1k1kDlClG2dGfhHw7wypmtfrOJBw
SNVwnkrA1x5bB+mZc+CC4X+ZUiICVsiJUss/woGjMvckNkkR8bP82sG/r3Fg
3+S+EOvVRGxVxElKyuLAzgapwaPqRDxUamAjUccBrYfNu6IMiDi0PFB4+TsH
FM5HlT3GRLz0ZWElTcgBsb07FGr3EHF29a8Af2Uu0DQ51wYOEbHp27Wqwzu4
8J38Ypp9nIiNssd+m3hyIXt6SYDaOSLWjyuuTL7MBb+vPpP7o4hYJzAkci6D
CxpvXh+7+i8Rax7YarP7DRems+XGSh8Ssdo2gWzuABfKEgJ8BwuJWFXl/aCQ
y4WQMw0ji6uIWEk8Ps9tNQ8MDykeNm4k4tUzDkGVJjxgm50Z9u0k4r+6Vpou
O8iD15qfPJKGiX/O1wAp4AIPImTXDb6bJuKmL7ZQmMYDsWLLw3wOEYdPvQ6f
esmDW7tOjJmKk7AeSctEs4cHfw0nBlxYQcJjihkMfwYPMi88n69UIeEHBkvL
C1YsgJpsdyhNh4Qd7cNPT25ZgNIiNlf3HxJe5DetqbF/AYx2/X3ltA0J10S4
jx8PWYDaoZ2Lip1JODCtNfvpnQWwvOATP+lDwuuf/eM98WwB2pfHyKgHk3Bf
c/HfGzsWwLmoMNk3goSd64lFdnMLEN76SrY8gYS7XruaBEvz4cnM+3+F9/74
K0ubUrT50CzdKW2fR8JtpWTnGjs+zG4evpleQcK7n7r9HArgw4q905ITQMJN
Wc9CSAl8MA3hxBq2k7DFAzHCxkI+eN8VE48aIOG6ZPfbdh/5cOOF3PWOCRLe
cat8TfAEH4q715KUmCT8OkaiOEVcAJ1M7asBJDLeetXTtEZNAGz5bcKqZWRc
efFF89AuASiZWF8WUyJj5ShriQlfAWxh2475bCLjuIRBK0qUAKxfOTjUbSVj
2t2gGO4TAXic21+lZEnGHhnkJlK9AEIMXVTC95NxU849MakfAoihu8X3eZOx
XomW5V8iAWRUeNKMTpPxg0q4rqwshOchR9yTL5Hxolqnxo07hPBBz6+REkvG
gR8myPoeQhiY99dxSCXjvvZwi23hQpgvO5VWnE3G5r3Loi0eCGFRYLBo8XMy
LhnOabCvEcJqnVD/Y7VkLD+xleTSJ4TNMxc6338i46nPkV0WbCE8LAtcpd9H
xm9ffcjWlxfBkhA/z0djZPw/xf9D6w==
        "]]}, 
      {RGBColor[0.528488, 0.470624, 0.701351], PointSize[
       0.004583333333333334], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwV13c4FX4XAHC7iGyijBAlJCFFDjKjCJEkkhVCQop+FFKpJKSErLLd4dry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        "]]}, 
      {RGBColor[0.772079, 0.431554, 0.102387], PointSize[
       0.004583333333333334], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwV1Wc41osfBvBnaC8lISUZTUeDhJPu34lEEllJEqKiDklEGRXHCBmlQhml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        "]]}}, {{}, {}}}, {}, {{}, {{{}, {}, {}, {}}, {}}}}, {{{}, {}}, {}, \
{{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      GeometricTransformationBox[InsetBox[
        StyleBox["\[FilledCircle]",
         StripOnInput->False,
         GraphicsBoxOptions->{DefaultBaseStyle->Directive[
           PointSize[0.012833333333333334`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]]}], {0., 0.}, Automatic, Offset[
        50]], {{{-0.049937771837002445`, -1.0012461141278124`}}, {{
       0.04993777183700243, 
       1.0012461141278126`}}}]}, {{}, {}}}, {}, {{}, {{{}, {}, {}, {}}, {}}}}},
  AspectRatio->Automatic,
  Axes->True,
  AxesOrigin->{0, 0},
  CoordinatesToolOptions:>{"DisplayFunction" -> (Identity[
       Part[#, 1]] + I Identity[
        Part[#, 2]]& ), "CopiedValueFunction" -> (Identity[
       Part[#, 1]] + I Identity[
        Part[#, 2]]& )},
  DisplayFunction->Identity,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{373., Automatic},
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "MessagesHead" -> ComplexListPlot},
  PlotRange->{{-2, 3}, {-2, 2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.825038887192035*^9, 3.825038927817092*^9, 3.825038978785578*^9, {
   3.8250390251450014`*^9, 3.825039053566888*^9}, 3.825039533348454*^9, 
   3.8250396081293316`*^9, 3.8250401744901676`*^9, 3.825040236707527*^9, 
   3.8250404803994865`*^9, 3.825040766516387*^9, 3.825041841473078*^9, 
   3.8250420188949404`*^9, 3.8250421088480763`*^9, 3.825042292613776*^9, 
   3.8250426400668793`*^9, 3.825042891066882*^9, 3.8250432423793187`*^9, {
   3.825043282270039*^9, 3.8250432924574986`*^9}, 3.8250438920356407`*^9, 
   3.825044075973096*^9, 3.8250444670044565`*^9, 3.8250451267856255`*^9, 
   3.8250452943481417`*^9, 3.8250454226140413`*^9, 3.8250456614261827`*^9, 
   3.8250461019887056`*^9, 3.825047178660862*^9, 3.8250475281762094`*^9, 
   3.8250528852647095`*^9, 3.8250532439715323`*^9, 3.8250537605543213`*^9, 
   3.8250541444645967`*^9, 3.8250543716140256`*^9, 3.8250546900828094`*^9, 
   3.825055140926216*^9, 3.8250557376137047`*^9, 3.825056111441887*^9, 
   3.8250565731451316`*^9, 3.825057252082528*^9, 3.825057318582635*^9, 
   3.825057479379449*^9, 3.82510375234797*^9, 3.825104584811177*^9, {
   3.82510462931707*^9, 3.8251046477856045`*^9}, {3.825135216739256*^9, 
   3.825135228833023*^9}, 3.825135320051409*^9, {3.825135425832877*^9, 
   3.8251354516608696`*^9}, 3.8251355378830385`*^9},
 CellLabel->
  "Out[1081]=",ExpressionUUID->"742376f3-ea96-4a75-b554-57e5e11f3d41"]
}, Open  ]]
},
WindowSize->{1904, 991},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
TaggingRules->{
 "WelcomeScreenSettings" -> {"FEStarting" -> True}, "TryRealOnly" -> False},
FrontEndVersion->"12.2 for Microsoft Windows (64-bit) (2021\:5e742\:67082\
\:65e5)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"d8ad1501-45a3-4fb6-ab47-a516cc4c16f2"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 677, 14, 108, "Input",ExpressionUUID->"bc70f9da-5b8a-493c-9dbf-7c6d8cd4633d"],
Cell[CellGroupData[{
Cell[1260, 38, 24653, 597, 1207, "Input",ExpressionUUID->"b64d2191-17bf-44d5-9569-bb0d8fa1db1c"],
Cell[25916, 637, 8797, 161, 248, "Output",ExpressionUUID->"d1319bcb-e1d5-4caa-ada4-6eb2474fa462"],
Cell[34716, 800, 2254, 43, 48, "Output",ExpressionUUID->"b3f524a0-8d2e-403b-9dc7-cc57f2a49bfa"],
Cell[36973, 845, 1483, 22, 32, "Output",ExpressionUUID->"1a2dc46c-ea9b-4fab-8cb0-c2da941fe077"],
Cell[38459, 869, 37325, 647, 321, "Output",ExpressionUUID->"3fdb8df1-4e70-4ca7-9dc1-8eec2c2f0ef7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75821, 1521, 352, 10, 48, "Input",ExpressionUUID->"50481924-8e00-4c4e-9053-71e97dfd0c9a"],
Cell[76176, 1533, 37393, 649, 321, "Output",ExpressionUUID->"742376f3-ea96-4a75-b554-57e5e11f3d41"]
}, Open  ]]
}
]
*)

